from pandas.io.common import stringify_path as stringify_path
from typing import Any, Optional

def read_sas(filepath_or_buffer: Any, format: Optional[Any] = ..., index: Optional[Any] = ..., encoding: Optional[Any] = ..., chunksize: Optional[Any] = ..., iterator: bool = ...) -> Any: ...
