from pandas._libs.tslibs import Timestamp as Timestamp
from typing import Any, Optional

def ensure_scope(level: int, global_dict: Any = ..., local_dict: Any = ..., resolvers: Any = ..., target: Any = ..., **kwargs: Any) -> Scope: ...

class Scope:
    level: Any = ...
    scope: Any = ...
    target: Any = ...
    resolvers: Any = ...
    temps: Any = ...
    def __init__(self, level: Any, global_dict: Optional[Any] = ..., local_dict: Optional[Any] = ..., resolvers: Any = ..., target: Optional[Any] = ...) -> None: ...
    @property
    def has_resolvers(self) -> bool: ...
    def resolve(self, key: str, is_local: bool) -> Any: ...
    def swapkey(self, old_key: str, new_key: str, new_value: Any = ...) -> Any: ...
    def add_tmp(self, value: Any) -> str: ...
    @property
    def ntemps(self) -> int: ...
    @property
    def full_scope(self) -> Any: ...
