from typing import Any, Callable, Dict, Optional

def get_keywords() -> Any: ...

class VersioneerConfig: ...

def get_config() -> Any: ...

class NotThisMethod(Exception): ...

HANDLERS: Dict[str, Dict[str, Callable[..., Any]]]

def register_vcs_handler(vcs: str, method: str) -> Callable[..., Any]: ...
def run_command(commands: Any, args: Any, cwd: Optional[Any] = ..., verbose: bool = ..., hide_stderr: bool = ...) -> Any: ...
def versions_from_parentdir(parentdir_prefix: Any, root: Any, verbose: Any) -> Any: ...
def git_get_keywords(versionfile_abs: Any) -> Any: ...
def git_versions_from_keywords(keywords: Any, tag_prefix: Any, verbose: Any) -> Any: ...
def git_pieces_from_vcs(tag_prefix: Any, root: Any, verbose: Any, run_command: Any = ...) -> Any: ...
def plus_or_dot(pieces: Any) -> Any: ...
def render_pep440(pieces: Any) -> Any: ...
def render_pep440_pre(pieces: Any) -> Any: ...
def render_pep440_post(pieces: Any) -> Any: ...
def render_pep440_old(pieces: Any) -> Any: ...
def render_git_describe(pieces: Any) -> Any: ...
def render_git_describe_long(pieces: Any) -> Any: ...
def render(pieces: Any, style: Any) -> Any: ...
def get_versions() -> Any: ...
