from pandas._libs.tslibs import parsing as parsing
from typing import Any

def parse_date_time(date_col: Any, time_col: Any) -> Any: ...
def parse_date_fields(year_col: Any, month_col: Any, day_col: Any) -> Any: ...
def parse_all_fields(year_col: Any, month_col: Any, day_col: Any, hour_col: Any, minute_col: Any, second_col: Any) -> Any: ...
def generic_parser(parse_func: Any, *cols: Any) -> Any: ...
