from typing import Any, Optional

def get_dtype_kinds(l: Any) -> Any: ...
def concat_compat(to_concat: Any, axis: int=...) -> Any: ...
def concat_categorical(to_concat: Any, axis: int=...) -> Any: ...
def union_categoricals(to_union: Any, sort_categories: bool=..., ignore_order: bool=...) -> Any: ...
def concat_datetime(to_concat: Any, axis: int = ..., typs: Optional[Any] = ...) -> Any: ...
