
from pandas.core.dtypes.generic import ABCDataFrame as ABCDataFrame, ABCIndexClass as ABCIndexClass, ABCSeries as ABCSeries
from pandas.plotting._matplotlib import compat as compat
from typing import Any, Optional

def format_date_labels(ax: Any, rot: Any) -> None: ...
def table(ax: Any, data: Any, rowLabels: Optional[Any] = ..., colLabels: Optional[Any] = ..., **kwargs: Any) -> Any: ...
