from pandas._libs import Timestamp as Timestamp
from pandas.core.dtypes.cast import infer_dtype_from_scalar as infer_dtype_from_scalar

from pandas.core.dtypes.generic import ABCDataFrame as ABCDataFrame, ABCIndexClass as ABCIndexClass, ABCMultiIndex as ABCMultiIndex, ABCSeries as ABCSeries
from pandas.core.dtypes.missing import isna as isna
from typing import Any, Optional

def hash_pandas_object(obj: Any, index: bool=..., encoding: str=..., hash_key: Optional[str]=..., categorize: bool=...) -> Any: ...
def hash_tuples(vals: Any, encoding: Any = ..., hash_key: str=...) -> Any: ...
def hash_tuple(val: Any, encoding: str=..., hash_key: str=...) -> Any: ...
def hash_array(vals: Any, encoding: str=..., hash_key: str=..., categorize: bool=...) -> Any: ...
