from pandas._config import get_option as get_option
from pandas.core.dtypes.generic import ABCDataFrame as ABCDataFrame
from typing import Any, Optional

def set_use_numexpr(v: bool = ...) -> None: ...
def set_numexpr_threads(n: Optional[Any] = ...) -> None: ...
def evaluate(op: Any, op_str: Any, a: Any, b: Any, use_numexpr: bool = ...) -> Any: ...
def where(cond: Any, a: Any, b: Any, use_numexpr: bool = ...) -> Any: ...
def set_test_mode(v: bool = ...) -> None: ...
def get_test_result() -> Any: ...
