from pandas.core.dtypes.generic import ABCDataFrame as ABCDataFrame, ABCIndexClass as ABCIndexClass
from pandas.plotting._matplotlib.core import LinePlot as LinePlot, MPLPlot as MPLPlot
from typing import Any, Optional

class HistPlot(LinePlot):
    bins: Any = ...
    bottom: Any = ...
    def __init__(self, data: Any, bins: int = ..., bottom: int = ..., **kwargs: Any) -> None: ...
    @property
    def orientation(self) -> Any: ...  # type: ignore

class KdePlot(HistPlot):
    orientation: str = ...
    bw_method: Any = ...
    ind: Any = ...
    def __init__(self, data: Any, bw_method: Optional[Any] = ..., ind: Optional[Any] = ..., **kwargs: Any) -> None: ...

def hist_series(self: Any, by: Optional[Any] = ..., ax: Optional[Any] = ..., grid: bool = ..., xlabelsize: Optional[Any] = ..., xrot: Optional[Any] = ..., ylabelsize: Optional[Any] = ..., yrot: Optional[Any] = ..., figsize: Optional[Any] = ..., bins: int = ..., **kwds: Any) -> Any: ...
def hist_frame(data: Any, column: Optional[Any] = ..., by: Optional[Any] = ..., grid: bool = ..., xlabelsize: Optional[Any] = ..., xrot: Optional[Any] = ..., ylabelsize: Optional[Any] = ..., yrot: Optional[Any] = ..., ax: Optional[Any] = ..., sharex: bool = ..., sharey: bool = ..., figsize: Optional[Any] = ..., layout: Optional[Any] = ..., bins: int = ..., **kwds: Any) -> Any: ...
