from pandas._config.config import options as options
from typing import Any, Optional

def set_locale(new_locale: Any, lc_var: Any = ...) -> None: ...
def can_set_locale(lc: Any, lc_var: Any = ...) -> Any: ...
def get_locales(prefix: Optional[Any] = ..., normalize: bool = ..., locale_getter: Any = ...) -> Any: ...
