from typing import Any, Optional

def convert_to_line_delimits(s: Any) -> Any: ...
def nested_to_record(ds: Any, prefix: str=..., sep: str=..., level: int=..., max_level: Optional[int]=...) -> Any: ...

json_normalize: Any
_json_normalize: Any
