from typing import Any

def cut(x: Any, bins: Any, right: bool=..., labels: Any = ..., retbins: bool=..., precision: int=..., include_lowest: bool=..., duplicates: str=...) -> Any: ...
def qcut(x: Any, q: Any, labels: Any = ..., retbins: bool=..., precision: int=..., duplicates: str=...) -> Any: ...
