from typing import Any

def radd(left: Any, right: Any) -> Any: ...
def rsub(left: Any, right: Any) -> Any: ...
def rmul(left: Any, right: Any) -> Any: ...
def rdiv(left: Any, right: Any) -> Any: ...
def rtruediv(left: Any, right: Any) -> Any: ...
def rfloordiv(left: Any, right: Any) -> Any: ...
def rmod(left: Any, right: Any) -> Any: ...
def rdivmod(left: Any, right: Any) -> Any: ...
def rpow(left: Any, right: Any) -> Any: ...
def rand_(left: Any, right: Any) -> Any: ...
def ror_(left: Any, right: Any) -> Any: ...
def rxor(left: Any, right: Any) -> Any: ...
