from typing import Any, Optional

gcsfs: Any

def get_filepath_or_buffer(filepath_or_buffer: Any, encoding: Optional[Any] = ..., compression: Optional[Any] = ..., mode: Optional[Any] = ...) -> Any: ...
