from pandas._libs.tslibs.timedeltas import Timedelta as Timedelta
from pandas.core.dtypes.generic import ABCIndexClass as ABCIndexClass, ABCSeries as ABCSeries
from typing import Any

def to_timedelta(arg: Any, unit: str = ..., errors: str = ...) -> Any: ...
