from typing import Any, Optional
from pandas.core.dtypes.missing import isna as isna

def mask_missing(arr: Any, values_to_mask: Any) -> Any: ...
def clean_fill_method(method: Any, allow_nearest: bool = ...) -> Any: ...
def clean_interp_method(method: Any, **kwargs: Any) -> Any: ...
def find_valid_index(values: Any, how: str) -> Any: ...
def interpolate_1d(xvalues: Any, yvalues: Any, method: str = ..., limit: Optional[Any] = ..., limit_direction: str = ..., limit_area: Optional[Any] = ..., fill_value: Optional[Any] = ..., bounds_error: bool = ..., order: Optional[Any] = ..., **kwargs: Any) -> Any: ...
def interpolate_2d(values: Any, method: str = ..., axis: int = ..., limit: Optional[Any] = ..., fill_value: Optional[Any] = ..., dtype: Optional[Any] = ...) -> Any: ...
def pad_1d(values: Any, limit: Optional[Any] = ..., mask: Optional[Any] = ..., dtype: Optional[Any] = ...) -> Any: ...
def backfill_1d(values: Any, limit: Optional[Any] = ..., mask: Optional[Any] = ..., dtype: Optional[Any] = ...) -> Any: ...
def pad_2d(values: Any, limit: Optional[Any] = ..., mask: Optional[Any] = ..., dtype: Optional[Any] = ...) -> Any: ...
def backfill_2d(values: Any, limit: Optional[Any] = ..., mask: Optional[Any] = ..., dtype: Optional[Any] = ...) -> Any: ...
def get_fill_func(method: Any) -> Any: ...
def clean_reindex_fill_method(method: Any) -> Any: ...
