from typing import Any, Iterable, Optional

class _DeprecatedModule:
    deprmod: Any = ...
    deprmodto: Any = ...
    removals: Any = ...
    moved: Any = ...
    self_dir: Any = ...
    def __init__(self, deprmod: Any, deprmodto: Optional[Any] = ..., removals: Optional[Any] = ..., moved: Optional[Any] = ...) -> None: ...
    def __dir__(self) -> Iterable[str]: ...
    def __getattr__(self, name: str) -> Any: ...
