from typing import Any

from pandas.core.dtypes.generic import ABCDataFrame as ABCDataFrame, ABCSeries as ABCSeries, ABCSparseArray as ABCSparseArray
from pandas.core.ops.roperator import radd as radd, rand_ as rand_, rdivmod as rdivmod, rfloordiv as rfloordiv, rmod as rmod, rmul as rmul, ror_ as ror_, rpow as rpow, rsub as rsub, rtruediv as rtruediv, rxor as rxor

def add_special_arithmetic_methods(cls: Any) -> Any: ...
def add_flex_arithmetic_methods(cls: Any) -> None: ...
