from collections import abc
from typing import Any, Optional

class XportReader(abc.Iterator[Any]):
    __doc__: Any = ...
    filepath_or_buffer: Any = ...
    def __init__(self, filepath_or_buffer: Any, index: Optional[Any] = ..., encoding: str = ..., chunksize: Optional[Any] = ...) -> None: ...
    def close(self) -> None: ...
    def __next__(self) -> Any: ...
    def get_chunk(self, size: Optional[Any] = ...) -> Any: ...
    def read(self, nrows: Optional[Any] = ...) -> Any: ...
