from pandas._typing import Scalar as Scalar
from typing import Any, Callable, Dict, Optional, Tuple

def make_rolling_apply(func: Callable[..., Scalar], args: Tuple[Any, ...], nogil: bool, parallel: bool, nopython: bool) -> Any: ...
def generate_numba_apply_func(args: Tuple[Any, ...], kwargs: Dict[str, Any], func: Callable[..., Scalar], engine_kwargs: Optional[Dict[str, bool]]) -> Any: ...
