import numpy as np

from typing import Any, Iterable, Union

def validate_args(fname: Any, args: Any, max_fname_arg_count: Any, compat_args: Any) -> None: ...
def validate_kwargs(fname: Any, kwargs: Any, compat_args: Any) -> None: ...
def validate_args_and_kwargs(fname: Any, args: Any, kwargs: Any, max_fname_arg_count: Any, compat_args: Any) -> None: ...
def validate_bool_kwarg(value: Any, arg_name: Any) -> Any: ...
def validate_axis_style_args(data: Any, args: Any, kwargs: Any, arg_name: Any, method_name: Any) -> Any: ...
def validate_fillna_kwargs(value: Any, method: Any, validate_scalar_dict_value: bool = ...) -> Any: ...
def validate_percentile(q: Union[float, Iterable[float]]) -> np.ndarray: ...
