from collections import namedtuple

from pandas.plotting._matplotlib.core import LinePlot as LinePlot
from typing import Any, Optional

class BoxPlot(LinePlot):
    return_type: Any = ...
    def __init__(self, data: Any, return_type: str = ..., **kwargs: Any) -> None: ...
    def maybe_color_bp(self, bp: Any) -> None: ...
    @property
    def orientation(self) -> str: ...  # type: ignore
    @property
    def result(self) -> Any: ...

def boxplot(data: Any, column: Optional[Any] = ..., by: Optional[Any] = ..., ax: Optional[Any] = ..., fontsize: Optional[Any] = ..., rot: int = ..., grid: bool = ..., figsize: Optional[Any] = ..., layout: Optional[Any] = ..., return_type: Optional[Any] = ..., **kwds: Any) -> Any: ...
def boxplot_frame(self: Any, column: Optional[Any] = ..., by: Optional[Any] = ..., ax: Optional[Any] = ..., fontsize: Optional[Any] = ..., rot: int = ..., grid: bool = ..., figsize: Optional[Any] = ..., layout: Optional[Any] = ..., return_type: Optional[Any] = ..., **kwds: Any) -> Any: ...
def boxplot_frame_groupby(grouped: Any, subplots: bool = ..., column: Optional[Any] = ..., fontsize: Optional[Any] = ..., rot: int = ..., grid: bool = ..., ax: Optional[Any] = ..., figsize: Optional[Any] = ..., layout: Optional[Any] = ..., sharex: bool = ..., sharey: bool = ..., **kwds: Any) -> Any: ...
