from collections import namedtuple

from typing import Any

OutputKey = namedtuple('OutputKey', ['label', 'position'])

class GroupByMixin: ...

plotting_methods: Any
common_apply_whitelist: Any
series_apply_whitelist: Any
dataframe_apply_whitelist: Any
cythonized_kernels: Any
cython_cast_blacklist: Any
reduction_kernels: Any
transformation_kernels: Any
groupby_other_methods: Any
transform_kernel_whitelist: Any
