
from pandas.core.ops.roperator import rdivmod as rdivmod, rfloordiv as rfloordiv, rmod as rmod
from typing import Any

def fill_zeros(result: Any, x: Any, y: Any) -> Any: ...
def mask_zero_div_zero(x: Any, y: Any, result: Any) -> Any: ...
def dispatch_fill_zeros(op: Any, left: Any, right: Any, result: Any) -> Any: ...
