
from pandas.core.dtypes.generic import ABCDataFrame as ABCDataFrame, ABCSeries as ABCSeries
from pandas.core.groupby.base import GroupByMixin as GroupByMixin
from pandas.core.indexes.api import MultiIndex as MultiIndex
from typing import Any, Callable, Optional, Sequence


class WindowGroupByMixin(GroupByMixin):
    def __init__(self, obj: Any, *args: Any, **kwargs: Any) -> None: ...
    count: Any = ...
    corr: Any = ...
    cov: Any = ...

def calculate_center_offset(window: Any) -> Any: ...
def calculate_min_periods(window: int, min_periods: Optional[int], num_values: int, required_min_periods: int, floor: int) -> int: ...
def zsqrt(x: Any) -> Any: ...
def prep_binary(arg1: Any, arg2: Any) -> Any: ...
def get_weighted_roll_func(cfunc: Callable[..., Any]) -> Callable[..., Any]: ...
