from pandas._config.config import is_bool as is_bool, is_callable as is_callable, is_instance_factory as is_instance_factory, is_int as is_int, is_nonnegative_int as is_nonnegative_int, is_one_of_factory as is_one_of_factory, is_text as is_text
from typing import Any

use_bottleneck_doc: str

def use_bottleneck_cb(key: Any) -> None: ...

use_numexpr_doc: str

def use_numexpr_cb(key: Any) -> None: ...

pc_precision_doc: str
pc_colspace_doc: str
pc_max_rows_doc: str
pc_min_rows_doc: str
pc_max_cols_doc: str
pc_max_categories_doc: str
pc_max_info_cols_doc: str
pc_nb_repr_h_doc: str
pc_pprint_nest_depth: str
pc_multi_sparse_doc: str
float_format_doc: str
max_colwidth_doc: str
colheader_justify_doc: str
pc_expand_repr_doc: str
pc_show_dimensions_doc: str
pc_east_asian_width_doc: str
pc_ambiguous_as_wide_doc: str
pc_latex_repr_doc: str
pc_table_schema_doc: str
pc_html_border_doc: str
pc_html_use_mathjax_doc: str
pc_width_doc: str
pc_chop_threshold_doc: str
pc_max_seq_items: str
pc_max_info_rows_doc: str
pc_large_repr_doc: str
pc_memory_usage_doc: str
pc_latex_escape: str
pc_latex_longtable: str
pc_latex_multicolumn: str
pc_latex_multicolumn_format: str
pc_latex_multirow: str

def table_schema_cb(key: Any) -> None: ...
def is_terminal() -> bool: ...

max_cols: int
tc_sim_interactive_doc: str
use_inf_as_null_doc: str
use_inf_as_na_doc: str

def use_inf_as_na_cb(key: Any) -> None: ...

chained_assignment: str
reader_engine_doc: str
writer_engine_doc: str
parquet_engine_doc: str
plotting_backend_doc: str

def register_plotting_backend_cb(key: Any) -> None: ...

register_converter_doc: str

def register_converter_cb(key: Any) -> None: ...
