from pandas._config import describe_option as describe_option, get_option as get_option, option_context as option_context, options as options, reset_option as reset_option, set_option as set_option
from pandas.core.api import BooleanDtype as BooleanDtype, Categorical as Categorical, CategoricalDtype as CategoricalDtype, CategoricalIndex as CategoricalIndex, DataFrame as DataFrame, DateOffset as DateOffset, DatetimeIndex as DatetimeIndex, DatetimeTZDtype as DatetimeTZDtype, Float64Index as Float64Index, Grouper as Grouper, Index as Index, IndexSlice as IndexSlice, Int16Dtype as Int16Dtype, Int32Dtype as Int32Dtype, Int64Dtype as Int64Dtype, Int64Index as Int64Index, Int8Dtype as Int8Dtype, Interval as Interval, IntervalDtype as IntervalDtype, IntervalIndex as IntervalIndex, MultiIndex as MultiIndex, NA as NA,  NamedAgg as NamedAgg, PeriodDtype as PeriodDtype, PeriodIndex as PeriodIndex, RangeIndex as RangeIndex, Series as Series, StringDtype as StringDtype, Timedelta as Timedelta, TimedeltaIndex as TimedeltaIndex, Timestamp as Timestamp, UInt16Dtype as UInt16Dtype, UInt32Dtype as UInt32Dtype, UInt64Dtype as UInt64Dtype, UInt64Index as UInt64Index, UInt8Dtype as UInt8Dtype, array as array, bdate_range as bdate_range, date_range as date_range, factorize as factorize, interval_range as interval_range, isna as isna, isnull as isnull, notna as notna, notnull as notnull, period_range as period_range, set_eng_float_format as set_eng_float_format, timedelta_range as timedelta_range, to_datetime as to_datetime, to_numeric as to_numeric, to_timedelta as to_timedelta, unique as unique, value_counts as value_counts
from pandas.core.arrays.sparse import SparseDtype as SparseDtype
from pandas.core.computation.api import eval as eval
from pandas.core.reshape.api import concat as concat, crosstab as crosstab, cut as cut, get_dummies as get_dummies, lreshape as lreshape, melt as melt, merge as merge, merge_asof as merge_asof, merge_ordered as merge_ordered, pivot as pivot, pivot_table as pivot_table, qcut as qcut, wide_to_long as wide_to_long
from pandas.io.api import ExcelFile as ExcelFile, ExcelWriter as ExcelWriter, HDFStore as HDFStore, read_clipboard as read_clipboard, read_csv as read_csv, read_excel as read_excel, read_feather as read_feather, read_fwf as read_fwf, read_gbq as read_gbq, read_hdf as read_hdf, read_html as read_html, read_json as read_json, read_orc as read_orc, read_parquet as read_parquet, read_pickle as read_pickle, read_sas as read_sas, read_spss as read_spss, read_sql as read_sql, read_sql_query as read_sql_query, read_sql_table as read_sql_table, read_stata as read_stata, read_table as read_table, to_pickle as to_pickle
from pandas.tseries import offsets as offsets
from pandas.tseries.api import infer_freq as infer_freq
from pandas.util._print_versions import show_versions as show_versions
from pandas.util._tester import test as test
from typing import Any

__docformat__: str
hard_dependencies: Any
missing_dependencies: Any
module: Any
v: Any
__git_version__: Any

def __getattr__(name: Any) -> Any: ...

class Panel: ...
class SparseDataFrame: ...
class SparseSeries: ...

class __numpy:
    np: Any = ...
    warnings: Any = ...
    def __init__(self) -> None: ...
    def __getattr__(self, item: Any) -> Any: ...

np: Any

class __Datetime(type):
    datetime: Any = ...
    def __getattr__(cls, item: Any) -> Any: ...
    def __instancecheck__(cls, other: Any) -> Any: ...

class __DatetimeSub(metaclass=__Datetime):
    def emit_warning(self, dummy: int = ...) -> None: ...
    def __new__(cls, *args: Any, **kwargs: Any) -> Any: ...

datetime: Any

class __SparseArray(type):
    SparseArray: Any = ...
    def __instancecheck__(cls, other: Any) -> Any: ...

class __SparseArraySub(metaclass=__SparseArray):
    def emit_warning(self, dummy: int = ...) -> None: ...
    def __new__(cls, *args: Any, **kwargs: Any) -> Any: ...

SparseArray: Any
