from pandas.core.groupby.generic import DataFrameGroupBy as DataFrameGroupBy, NamedAgg as NamedAgg, SeriesGroupBy as SeriesGroupBy
from pandas.core.groupby.groupby import GroupBy as GroupBy
from pandas.core.groupby.grouper import Grouper as Grouper
