from typing import Any

magic: Any
align_1_checker_value: bytes
align_1_offset: int
align_1_length: int
align_1_value: int
u64_byte_checker_value: bytes
align_2_offset: int
align_2_length: int
align_2_value: int
endianness_offset: int
endianness_length: int
platform_offset: int
platform_length: int
encoding_offset: int
encoding_length: int
dataset_offset: int
dataset_length: int
file_type_offset: int
file_type_length: int
date_created_offset: int
date_created_length: int
date_modified_offset: int
date_modified_length: int
header_size_offset: int
header_size_length: int
page_size_offset: int
page_size_length: int
page_count_offset: int
page_count_length: int
sas_release_offset: int
sas_release_length: int
sas_server_type_offset: int
sas_server_type_length: int
os_version_number_offset: int
os_version_number_length: int
os_maker_offset: int
os_maker_length: int
os_name_offset: int
os_name_length: int
page_bit_offset_x86: int
page_bit_offset_x64: int
subheader_pointer_length_x86: int
subheader_pointer_length_x64: int
page_type_offset: int
page_type_length: int
block_count_offset: int
block_count_length: int
subheader_count_offset: int
subheader_count_length: int
page_meta_type: int
page_data_type: int
page_amd_type: int
page_metc_type: int
page_comp_type: int
page_mix_types: Any
subheader_pointers_offset: int
truncated_subheader_id: int
compressed_subheader_id: int
compressed_subheader_type: int
text_block_size_length: int
row_length_offset_multiplier: int
row_count_offset_multiplier: int
col_count_p1_multiplier: int
col_count_p2_multiplier: int
row_count_on_mix_page_offset_multiplier: int
column_name_pointer_length: int
column_name_text_subheader_offset: int
column_name_text_subheader_length: int
column_name_offset_offset: int
column_name_offset_length: int
column_name_length_offset: int
column_name_length_length: int
column_data_offset_offset: int
column_data_length_offset: int
column_data_length_length: int
column_type_offset: int
column_type_length: int
column_format_text_subheader_index_offset: int
column_format_text_subheader_index_length: int
column_format_offset_offset: int
column_format_offset_length: int
column_format_length_offset: int
column_format_length_length: int
column_label_text_subheader_index_offset: int
column_label_text_subheader_index_length: int
column_label_offset_offset: int
column_label_offset_length: int
column_label_length_offset: int
column_label_length_length: int
rle_compression: bytes
rdc_compression: bytes
compression_literals: Any
encoding_names: Any

class SASIndex:
    row_size_index: int = ...
    column_size_index: int = ...
    subheader_counts_index: int = ...
    column_text_index: int = ...
    column_name_index: int = ...
    column_attributes_index: int = ...
    format_and_label_index: int = ...
    column_list_index: int = ...
    data_subheader_index: int = ...

subheader_signature_to_index: Any
sas_date_formats: Any
sas_datetime_formats: Any
