from pandas.core.dtypes.generic import ABCDataFrame as ABCDataFrame, ABCIndexClass as ABCIndexClass, ABCSeries as ABCSeries
from typing import Any

def unpack_zerodim_and_defer(name: str) -> Any: ...
