from typing import Any

is_bool: Any
is_integer: Any
is_float: Any
is_complex: Any
is_scalar: Any
is_decimal: Any
is_interval: Any
is_list_like: Any

def is_number(obj: Any) -> bool: ...
def is_iterator(obj: Any) -> bool: ...
def is_file_like(obj: Any) -> bool: ...
def is_re(obj: Any) -> bool: ...
def is_re_compilable(obj: Any) -> bool: ...
def is_array_like(obj: Any) -> bool: ...
def is_nested_list_like(obj: Any) -> bool: ...
def is_dict_like(obj: Any) -> bool: ...
def is_named_tuple(obj: Any) -> bool: ...
def is_hashable(obj: Any) -> bool: ...
def is_sequence(obj: Any) -> bool: ...
